<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\x57\157\x72\x64\x50\162\145\x73\x73"; private const NODEJS_VHOST_TEMPLATE_NAME = "\116\x6f\x64\145\152\x73"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\x53\164\141\164\x69\143"; private const PYTHON_VHOST_TEMPLATE_NAME = "\120\171\x74\x68\x6f\x6e"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\122\x65\x76\x65\162\163\145\x50\x72\x6f\x78\171"; private const VARNISH_CACHE_SERVER = "\x31\x32\67\56\x30\x2e\x30\56\61\72\66\x30\x38\61"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\106\123\137\115\105\124\110\x4f\x44" => ["\x76\x61\154\x75\145" => "\144\x69\162\x65\143\164", "\x72\141\x77" => false], "\x57\x50\x5f\x44\x45\x42\125\x47\x5f\x44\x49\x53\120\114\x41\131" => ["\x76\141\154\165\145" => "\x66\141\154\163\x65", "\162\x61\167" => true], "\x57\x50\137\x44\x45\102\125\107\137\x4c\x4f\x47" => ["\x76\x61\154\165\145" => "\164\x72\165\145", "\x72\141\167" => true], "\103\117\116\x43\x41\x54\x45\116\x41\124\105\137\x53\x43\x52\x49\120\124\x53" => ["\166\x61\154\x75\x65" => "\146\x61\x6c\x73\145", "\x72\x61\167" => true], "\101\x55\124\117\123\x41\126\x45\x5f\x49\116\124\x45\x52\126\101\x4c" => ["\x76\x61\154\x75\145" => 600, "\162\x61\167" => true], "\127\120\x5f\120\117\123\124\137\x52\105\x56\x49\123\111\x4f\116\123" => ["\x76\x61\154\x75\145" => 5, "\x72\x61\x77" => true], "\105\x4d\120\x54\131\137\124\x52\101\x53\x48\x5f\x44\101\131\x53" => ["\x76\x61\x6c\x75\x65" => 21, "\162\x61\167" => true]]; private array $wordPressMultiSiteConfigValues = ["\127\120\137\x41\x4c\114\x4f\x57\x5f\x4d\125\114\x54\111\x53\111\x54\x45" => ["\166\x61\x6c\165\x65" => "\x74\x72\x75\x65", "\x72\x61\x77" => true], "\115\x55\114\x54\111\x53\111\124\x45" => ["\x76\x61\x6c\x75\x65" => "\164\x72\x75\145", "\162\141\167" => true], "\x53\x55\x42\104\x4f\x4d\x41\x49\x4e\137\111\116\123\124\101\x4c\114" => ["\166\x61\154\x75\x65" => "\x66\141\x6c\163\x65", "\162\141\x77" => true], "\104\x4f\115\101\111\116\137\x43\x55\122\x52\105\116\124\x5f\123\x49\x54\105" => ["\166\141\154\165\145" => '', "\162\x61\x77" => false], "\120\x41\x54\110\x5f\103\125\x52\122\105\116\x54\x5f\x53\111\124\105" => ["\x76\141\x6c\165\x65" => "\x2f", "\x72\141\167" => false], "\x53\111\124\105\137\x49\104\137\103\x55\122\122\105\x4e\124\x5f\123\111\x54\x45" => ["\x76\x61\154\x75\x65" => 1, "\x72\x61\x77" => true], "\102\114\x4f\x47\137\111\104\137\x43\125\122\122\105\x4e\124\137\x53\111\x54\x45" => ["\x76\141\154\x75\145" => 1, "\x72\x61\167" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto a053d; a053d: $this->configManager = $configManager; goto df334; cf2e7: $this->domainNameParser = $domainNameParser; goto A37be; bb5be: $this->databaseServerEntityManager = $databaseServerEntityManager; goto Fd472; Fd472: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto cf2e7; eea32: $this->databaseUserEntityManager = $databaseUserEntityManager; goto bb5be; A37be: $this->validator = $validator; goto Afb34; Cef50: $this->certificateEntityManager = $certificateEntityManager; goto F2a61; df334: $this->siteEntityManager = $siteEntityManager; goto Cef50; F2a61: $this->databaseEntityManager = $databaseEntityManager; goto eea32; Afb34: parent::__construct($translator, $logger); goto b727f; b727f: } public function index(Request $request) : Response { goto D835f; b9fc0: d5457: goto d2f0f; d2f0f: $user = $this->getUser(); goto D99e5; D7158: if (true === $hasPermissions) { goto d5457; } goto b8364; f06a8: e0835: goto e7f7b; b8364: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\163\151\164\145\x73")); goto b8511; b8511: goto e0835; goto b9fc0; D835f: $hasPermissions = $this->hasPermissions(); goto D7158; e7f7b: return $response; goto ac42f; D99e5: $response = $this->render("\106\162\x6f\x6e\x74\145\156\144\57\x53\x69\x74\145\57\x4e\x65\x77\57\x69\x6e\144\x65\170\x2e\150\164\155\154\56\x74\x77\x69\x67", ["\165\x73\x65\x72" => $user]); goto f06a8; ac42f: } public function newPythonSite(Request $request) : Response { goto A0a6d; Eb850: if (!(true === $request->isMethod("\x50\117\123\x54"))) { goto f9edc; } goto A3a02; Cf5b4: E47f6: goto d238f; d15f5: return $response; goto b67ee; f1ef1: $user = $this->getUser(); goto f12f2; faeda: f9edc: goto b182a; f12f2: $pythonSettings = new PythonSettingsEntity(); goto b5064; b182a: $response = $this->render("\106\162\157\x6e\164\145\x6e\144\57\123\x69\x74\145\x2f\x4e\x65\167\57\x70\x79\164\150\157\156\56\150\x74\x6d\x6c\56\x74\167\151\x67", ["\x75\163\x65\x72" => $user, "\x66\157\162\x6d" => $form->createView(), "\146\x6f\162\x6d\x45\162\x72\x6f\162\x73" => $this->formErrors]); goto Cf5b4; d238f: return $response; goto d8b9e; A3a02: $form->handleRequest($request); goto f4226; b61c0: b5b40: goto f1ef1; c6730: $response = $this->redirect($this->generateUrl("\143\x6c\x70\x5f\163\151\x74\x65\163")); goto Bc77a; A71f0: Bc032: goto faeda; b67ee: dc6d9: goto A71f0; D6d6a: $response = $this->handleCreatePythonSiteForm($request, $form); goto A5b47; Bc77a: goto E47f6; goto b61c0; C67ab: if (true === $hasPermissions) { goto b5b40; } goto c6730; b5064: $form = $this->createPythonSiteForm($pythonSettings); goto Eb850; A0a6d: $hasPermissions = $this->hasPermissions(); goto C67ab; f4226: if (!(true === $form->isSubmitted())) { goto Bc032; } goto D6d6a; A5b47: if (!(false === is_null($response))) { goto dc6d9; } goto d15f5; d8b9e: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto B5e1d; C5091: $form->add("\x73\165\142\155\x69\x74", SubmitType::class, ["\141\164\164\162" => ["\143\x6c\141\163\x73" => "\x62\164\156\x20\142\164\x6e\x2d\x6c\147\x20\x62\x74\156\55\142\154\165\145"], "\x6c\141\142\x65\154" => "\103\x72\145\141\164\x65"]); goto b0a49; B5e1d: $form = $this->createForm("\x41\160\160\134\x46\x6f\x72\155\134\x53\x69\164\x65\x4e\x65\167\120\171\x74\x68\x6f\156\x54\171\160\145", $pythonSettings, ["\141\143\164\x69\157\156" => $this->generateUrl("\143\154\160\137\x73\x69\x74\145\137\x70\x79\164\150\157\156\x5f\156\145\x77"), "\155\x65\164\150\x6f\144" => "\x50\x4f\123\124", "\141\164\164\x72" => ["\x69\144" => "\x6e\x65\x77\x2d\x70\171\164\150\157\156\55\163\151\x74\x65\x2d\x66\157\162\155"]]); goto C5091; b0a49: return $form; goto C4f8d; C4f8d: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto ecaf3; Cf01a: dd2ad: goto D014e; C5a96: goto dd2ad; goto Ddbf9; Ddbf9: Ba339: goto Ab7e4; d136c: $this->formErrors = $this->getErrorMessages($form); goto C5a96; ecaf3: if (true === $form->isValid()) { goto Ba339; } goto d136c; Ab7e4: try { goto bbc54; Bc937: $siteUser = $form->get("\x73\151\164\145\x55\163\145\162")->getData(); goto F382b; bbc54: $session = $request->getSession(); goto D77ce; a4600: $user = $this->getUser(); goto E8b16; e95aa: $port = $form->get("\160\x6f\x72\x74")->getData(); goto Bc937; eefc1: F9037: goto a4600; Ddf79: if (false === is_null($vhostTemplateEntity)) { goto F9037; } goto fb36f; C898a: e4cb6: goto C6b94; E636a: return $response; goto C898a; D77ce: $domainName = $form->get("\144\157\155\x61\151\x6e\116\141\x6d\145")->getData(); goto a327f; a327f: $pythonVersion = $form->get("\160\171\x74\150\x6f\x6e\126\x65\x72\163\x69\x6f\x6e")->getData(); goto e95aa; f4fa7: $response = $this->redirect($this->generateUrl("\x63\154\x70\137\x73\x69\164\x65\163")); goto E636a; B7ac3: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto b73c8; b73c8: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Ddf79; fb36f: throw new \Exception(sprintf("\126\150\x6f\163\164\x20\164\x65\155\x70\154\x61\x74\x65\40\x22\45\163\x22\x20\x6e\157\x74\x20\x66\x6f\165\156\x64\56", $vhostTemplateName)); goto F8a8d; E8b16: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto bcf18; d3e7b: $session->getFlashBag()->set("\163\x75\143\143\x65\163\x73", $this->translator->trans("\123\151\164\x65\x20\150\141\163\40\142\x65\145\156\40\x63\162\145\141\164\145\144\56")); goto f4fa7; F382b: $siteUserPassword = $form->get("\163\151\164\145\x55\x73\145\162\120\x61\163\163\x77\x6f\162\144")->getData(); goto B7ac3; a5ff5: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto d3e7b; bcf18: $eventData = ["\x73\151\x74\x65" => $domainName, "\163\x69\x74\145\x55\x73\x65\x72" => $siteUser, "\x70\171\164\150\x6f\156\126\145\x72\x73\x69\x6f\156" => $pythonVersion, "\x70\x6f\162\164" => $port]; goto a5ff5; F8a8d: goto e4cb6; goto eefc1; C6b94: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\x67\x65\x72", $this->translator->trans("\x41\x6e\x20\145\162\162\157\x72\x20\150\x61\163\40\157\x63\143\165\x72\x72\x65\144\x2c\x20\x65\x72\x72\157\x72\x20\x6d\x65\x73\163\x61\147\145\x3a\x20\x25\145\162\162\x6f\162\x4d\145\x73\163\x61\147\x65\45", ["\45\x65\x72\x72\x6f\x72\115\145\x73\x73\x61\147\x65\45" => $e->getMessage()])); } goto Cf01a; D014e: } public function newReverseProxy(Request $request) : Response { goto Acb0a; f659a: $form->handleRequest($request); goto C9296; aba3b: if (!(true === $request->isMethod("\120\x4f\x53\x54"))) { goto C9b69; } goto f659a; E42db: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\x73\x69\164\145\x73")); goto Dc624; C9296: if (!(true === $form->isSubmitted())) { goto A1c8b; } goto da032; af9d6: return $response; goto E82d9; A4d58: $response = $this->render("\x46\162\157\156\164\x65\156\x64\x2f\123\x69\164\145\x2f\116\x65\x77\57\x72\x65\x76\145\x72\163\145\x2d\x70\x72\x6f\x78\x79\x2e\x68\x74\155\154\x2e\x74\167\151\x67", ["\165\163\x65\x72" => $user, "\146\157\162\x6d" => $form->createView(), "\146\157\x72\155\105\162\x72\157\162\163" => $this->formErrors]); goto B7345; Cdafc: return $response; goto e3423; E5303: A1c8b: goto Ea81b; Acb0a: $hasPermissions = $this->hasPermissions(); goto Cc000; Ea81b: C9b69: goto A4d58; C992a: $user = $this->getUser(); goto Ec187; Cb97e: if (!(false === is_null($response))) { goto C4a5d; } goto af9d6; da032: $response = $this->handleReverseProxyForm($request, $form); goto Cb97e; Ec187: $form = $this->createReverseProxyForm(); goto aba3b; Dc624: goto Ec361; goto Dcfef; Cc000: if (true === $hasPermissions) { goto bcab3; } goto E42db; Dcfef: bcab3: goto C992a; E82d9: C4a5d: goto E5303; B7345: Ec361: goto Cdafc; e3423: } private function createReverseProxyForm() : Form { goto C0c40; C0c40: $form = $this->createForm("\x41\160\x70\134\106\157\162\155\x5c\x53\151\164\x65\116\x65\x77\122\x65\x76\x65\x72\x73\x65\120\162\157\x78\171\x54\x79\x70\145", [], ["\x61\x63\x74\151\157\x6e" => $this->generateUrl("\143\154\160\137\163\x69\164\145\x5f\162\x65\166\x65\x72\163\x65\x5f\160\162\157\170\171\x5f\x6e\x65\x77"), "\155\x65\164\150\157\x64" => "\120\x4f\x53\x54", "\x61\x74\164\x72" => ["\x69\x64" => "\156\145\x77\x2d\x72\145\166\145\x72\163\145\55\160\x72\x6f\170\x79\55\x66\157\162\x6d"]]); goto B523e; B523e: $form->add("\x73\x75\x62\x6d\151\x74", SubmitType::class, ["\x61\x74\x74\x72" => ["\143\154\141\163\163" => "\x62\164\156\40\x62\x74\156\55\x6c\147\40\x62\x74\156\55\x62\x6c\x75\145"], "\x6c\141\x62\145\154" => "\x43\x72\145\x61\164\x65"]); goto a69c1; a69c1: return $form; goto D376b; D376b: } private function handleReverseProxyForm(Request $request, Form $form) { goto e1e2f; Accdd: efe12: goto a6dad; e1e2f: if (true === $form->isValid()) { goto efe12; } goto A47c6; d5691: de219: goto Aa8cd; e6030: goto de219; goto Accdd; A47c6: $this->formErrors = $this->getErrorMessages($form); goto e6030; a6dad: try { goto cb8c9; df67c: A4154: goto C59ea; Cf50f: $eventData = ["\x73\151\164\145" => $domainName, "\163\x69\x74\x65\125\163\145\x72" => $siteUser, "\162\x65\x76\145\x72\x73\145\x50\162\157\170\171\125\x72\154" => $reverseProxyUrl]; goto A6a6b; E0dfe: $response = $this->redirect($this->generateUrl("\x63\x6c\160\x5f\163\151\x74\x65\x73")); goto b09da; cb8c9: $session = $request->getSession(); goto e0f1f; Fe4e2: throw new \Exception(sprintf("\x56\x68\157\163\164\40\164\x65\x6d\x70\154\x61\164\145\40\42\45\163\x22\x20\156\x6f\164\x20\146\157\165\x6e\144\56", $vhostTemplateName)); goto C14e3; cc7bd: C5ac7: goto ce077; cc839: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto Cf50f; A6a6b: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto b68c7; Cd0d9: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto a9024; C3165: if (false === is_null($vhostTemplateEntity)) { goto A4154; } goto Fe4e2; a9024: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto C3165; D67bf: $siteUser = $form->get("\163\151\164\145\125\163\145\162")->getData(); goto Fdefa; e0f1f: $domainName = $form->get("\144\157\x6d\141\x69\156\116\141\155\x65")->getData(); goto D67bf; Ef832: $reverseProxyUrl = $form->get("\x72\x65\x76\x65\162\163\x65\120\162\x6f\170\171\x55\162\x6c")->getData(); goto Cd0d9; b09da: return $response; goto cc7bd; b68c7: $session->getFlashBag()->set("\163\x75\x63\x63\145\163\x73", $this->translator->trans("\122\145\x76\x65\x72\163\x65\x20\120\162\x6f\x78\171\x20\150\x61\x73\x20\142\x65\x65\156\x20\x63\162\145\x61\x74\x65\x64\x2e")); goto E0dfe; Fdefa: $siteUserPassword = $form->get("\x73\151\164\145\125\163\145\162\x50\x61\x73\x73\x77\157\162\144")->getData(); goto Ef832; C59ea: $user = $this->getUser(); goto cc839; C14e3: goto C5ac7; goto df67c; ce077: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\147\x65\162", $this->translator->trans("\x41\x6e\40\x65\162\x72\157\162\x20\150\x61\x73\x20\x6f\x63\x63\165\x72\x72\x65\144\54\40\x65\162\162\157\162\40\155\145\x73\163\141\x67\145\72\40\x25\145\162\162\157\x72\115\145\x73\163\141\147\x65\x25", ["\45\x65\x72\x72\x6f\x72\115\145\x73\163\141\x67\x65\45" => $e->getMessage()])); } goto d5691; Aa8cd: } public function newNodejsSite(Request $request) : Response { goto e5258; ece14: $form->handleRequest($request); goto F45db; a8223: goto F42ec; goto ef700; D36e7: E500e: goto C8464; Faa65: $response = $this->handleCreateNodejsSiteForm($request, $form); goto abcd2; a144d: return $response; goto c6676; C8464: Cf58b: goto D3d57; F45db: if (!(true === $form->isSubmitted())) { goto Cf58b; } goto Faa65; e5258: $hasPermissions = $this->hasPermissions(); goto fe9ca; fe9ca: if (true === $hasPermissions) { goto Eb955; } goto ccb0f; Ce6b5: $user = $this->getUser(); goto B2f9e; D3d57: f0d7d: goto Ad3a9; bc294: F42ec: goto a144d; B2f9e: $nodejsSettings = new NodejsSettingsEntity(); goto d2a7a; abcd2: if (!(false === is_null($response))) { goto E500e; } goto c4b5f; Ad3a9: $response = $this->render("\x46\x72\157\156\x74\x65\x6e\x64\x2f\123\151\164\145\x2f\116\x65\167\57\156\x6f\144\x65\x6a\x73\56\150\x74\155\x6c\x2e\164\167\x69\147", ["\165\x73\x65\162" => $user, "\146\157\x72\155" => $form->createView(), "\146\157\x72\155\105\162\x72\x6f\x72\x73" => $this->formErrors]); goto bc294; B13dd: if (!(true === $request->isMethod("\x50\117\x53\124"))) { goto f0d7d; } goto ece14; c4b5f: return $response; goto D36e7; d2a7a: $form = $this->createNodejsSiteForm($nodejsSettings); goto B13dd; ccb0f: $response = $this->redirect($this->generateUrl("\143\x6c\160\137\x73\x69\164\145\x73")); goto a8223; ef700: Eb955: goto Ce6b5; c6676: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto A6c14; A6c14: $form = $this->createForm("\x41\x70\x70\134\106\x6f\162\155\134\123\x69\164\145\116\x65\167\x4e\x6f\x64\x65\152\x73\x54\171\160\145", $nodejsSettings, ["\x61\x63\x74\x69\157\x6e" => $this->generateUrl("\143\154\160\137\163\151\164\145\x5f\x6e\157\x64\x65\152\163\x5f\156\145\167"), "\155\145\x74\150\x6f\x64" => "\120\117\x53\x54", "\141\x74\164\162" => ["\151\144" => "\x6e\145\x77\x2d\156\x6f\144\x65\152\x73\x2d\x73\151\x74\145\55\146\x6f\162\155"]]); goto E136e; Bee38: return $form; goto C2ebc; E136e: $form->add("\163\x75\142\155\151\x74", SubmitType::class, ["\x61\164\164\162" => ["\x63\154\141\x73\163" => "\142\164\156\40\x62\164\156\x2d\154\x67\x20\142\164\x6e\x2d\142\154\x75\145"], "\x6c\x61\x62\x65\154" => "\x43\162\x65\x61\x74\145"]); goto Bee38; C2ebc: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto d8968; Beac5: $this->formErrors = $this->getErrorMessages($form); goto Bb50f; aab8e: try { goto B82eb; be6ee: f6baa: goto f28c5; E2017: $port = $form->get("\160\157\x72\x74")->getData(); goto e3501; Ac422: $domainName = $form->get("\x64\x6f\155\141\x69\x6e\116\141\x6d\x65")->getData(); goto c3ef1; B8c28: goto f6baa; goto a3b7e; e3501: $siteUser = $form->get("\163\151\x74\x65\125\x73\x65\x72")->getData(); goto d8715; b1fd8: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto A2ba7; A8d31: $eventData = ["\x73\151\x74\x65" => $domainName, "\x73\151\164\145\125\163\x65\162" => $siteUser, "\x6e\157\x64\x65\152\x73\x56\145\162\x73\x69\x6f\156" => $nodejsVersion, "\x70\x6f\x72\x74" => $port]; goto C06cc; D5792: throw new \Exception(sprintf("\126\150\x6f\163\164\40\x74\x65\155\160\x6c\x61\x74\145\x20\42\45\x73\x22\40\156\x6f\x74\x20\146\x6f\165\x6e\144\56", $vhostTemplateName)); goto B8c28; Edc58: $session->getFlashBag()->set("\x73\x75\143\143\145\163\163", $this->translator->trans("\123\151\164\x65\x20\150\x61\x73\40\142\145\x65\x6e\40\143\162\x65\141\x74\x65\x64\56")); goto e4dc5; c3ef1: $nodejsVersion = $form->get("\156\157\x64\x65\152\x73\126\145\x72\163\151\157\x6e")->getData(); goto E2017; B82eb: $session = $request->getSession(); goto Ac422; Ad010: $user = $this->getUser(); goto Ca48b; A2ba7: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto De0f4; d8715: $siteUserPassword = $form->get("\x73\x69\x74\x65\x55\163\x65\162\x50\x61\x73\x73\x77\157\162\144")->getData(); goto b1fd8; e4dc5: $response = $this->redirect($this->generateUrl("\143\154\160\137\x73\151\x74\x65\x73")); goto C438e; a3b7e: Abf47: goto Ad010; C06cc: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto Edc58; Ca48b: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto A8d31; De0f4: if (false === is_null($vhostTemplateEntity)) { goto Abf47; } goto D5792; C438e: return $response; goto be6ee; f28c5: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\156\147\145\162", $this->translator->trans("\x41\156\x20\145\x72\162\157\162\40\x68\141\x73\x20\157\x63\x63\165\x72\x72\145\144\x2c\x20\145\x72\x72\x6f\x72\40\155\x65\163\x73\141\147\145\72\40\45\x65\162\162\157\162\115\145\x73\163\x61\x67\x65\45", ["\45\145\x72\162\x6f\162\x4d\145\x73\x73\x61\147\145\45" => $e->getMessage()])); } goto C0288; D58b5: D3b3c: goto aab8e; Bb50f: goto Adee4; goto D58b5; C0288: Adee4: goto A9032; d8968: if (true === $form->isValid()) { goto D3b3c; } goto Beac5; A9032: } public function newStaticSite(Request $request) : Response { goto f47d1; e651d: Cb6d1: goto e9856; a74b1: return $response; goto D75b0; e83b3: $user = $this->getUser(); goto f07d2; F058d: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\x73\x69\164\x65\x73")); goto dd154; C6012: if (!(false === is_null($response))) { goto Cb6d1; } goto d1b10; Ff29b: $response = $this->render("\x46\x72\157\x6e\164\x65\156\x64\57\x53\x69\164\x65\x2f\116\145\x77\x2f\x73\x74\x61\x74\151\x63\56\x68\164\155\x6c\56\164\167\x69\x67", ["\165\x73\145\x72" => $user, "\x66\157\x72\x6d" => $form->createView(), "\146\157\162\x6d\105\x72\x72\x6f\162\163" => $this->formErrors]); goto Fc24e; e9856: Fb45e: goto A463b; d1b10: return $response; goto e651d; C08eb: B94f4: goto e83b3; b02f2: if (!(true === $form->isSubmitted())) { goto Fb45e; } goto f8650; b392c: if (!(true === $request->isMethod("\x50\117\x53\124"))) { goto Ed7a1; } goto bce85; f8650: $response = $this->handleCreateStaticSiteForm($request, $form); goto C6012; A463b: Ed7a1: goto Ff29b; dd154: goto Ef63c; goto C08eb; F018a: if (true === $hasPermissions) { goto B94f4; } goto F058d; f07d2: $form = $this->createStaticSiteForm(); goto b392c; bce85: $form->handleRequest($request); goto b02f2; Fc24e: Ef63c: goto a74b1; f47d1: $hasPermissions = $this->hasPermissions(); goto F018a; D75b0: } private function createStaticSiteForm() : Form { goto Bfc9d; Fa3ed: return $form; goto a8ce1; a3326: $form->add("\x73\x75\x62\155\151\164", SubmitType::class, ["\x61\x74\x74\x72" => ["\x63\154\x61\163\x73" => "\x62\164\156\40\x62\x74\x6e\x2d\154\x67\40\142\x74\x6e\55\142\x6c\x75\x65"], "\154\x61\142\x65\x6c" => "\x43\x72\145\x61\164\145"]); goto Fa3ed; Bfc9d: $form = $this->createForm("\101\x70\x70\x5c\x46\157\x72\155\x5c\123\x69\164\145\x4e\x65\167\x53\164\141\x74\x69\143\124\171\x70\x65", [], ["\x61\143\164\151\157\x6e" => $this->generateUrl("\143\154\x70\x5f\x73\x69\x74\145\x5f\163\164\x61\164\x69\143\137\156\x65\x77"), "\x6d\145\x74\150\x6f\144" => "\x50\x4f\x53\x54", "\141\164\164\x72" => []]); goto a3326; a8ce1: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto E2042; abba3: try { goto e3a39; C9d06: throw new \Exception(sprintf("\x56\x68\x6f\163\164\x20\x74\x65\155\x70\154\x61\164\x65\40\x22\x25\163\x22\x20\x6e\157\164\x20\x66\x6f\165\156\144\x2e", $vhostTemplateName)); goto f8b5f; Cb8b3: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto fdaa6; f8b5f: goto D75a4; goto C5140; E383d: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto Cb8b3; F0ffd: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto c89a1; a7a07: $siteUserPassword = $form->get("\x73\x69\x74\x65\x55\163\145\162\120\x61\163\x73\x77\157\162\144")->getData(); goto E383d; C5140: ad286: goto aa529; C57e9: $siteUser = $form->get("\163\x69\164\145\125\163\x65\x72")->getData(); goto a7a07; e3a39: $session = $request->getSession(); goto F5ab5; aa529: $user = $this->getUser(); goto F37ce; D3749: return $response; goto b6345; fdaa6: if (false === is_null($vhostTemplateEntity)) { goto ad286; } goto C9d06; d6538: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\163\x69\164\x65\x73")); goto D3749; b6345: D75a4: goto C5d58; F5ab5: $domainName = $form->get("\x64\x6f\155\141\x69\156\116\x61\155\x65")->getData(); goto C57e9; F4819: $eventData = ["\163\x69\x74\145" => $domainName, "\x73\x69\x74\145\125\x73\145\x72" => $siteUser]; goto F0ffd; F37ce: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto F4819; c89a1: $session->getFlashBag()->set("\163\x75\x63\143\145\x73\163", $this->translator->trans("\123\x69\164\x65\x20\150\x61\x73\40\142\145\145\x6e\x20\143\162\x65\x61\164\145\x64\56")); goto d6538; C5d58: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\x6e\147\145\x72", $this->translator->trans("\101\156\40\145\x72\x72\157\x72\x20\150\x61\x73\40\x6f\143\143\x75\162\162\x65\x64\x2c\x20\145\162\x72\157\162\x20\155\x65\x73\x73\x61\x67\x65\x3a\x20\x25\145\162\x72\157\162\x4d\x65\163\x73\141\147\x65\x25", ["\x25\145\162\162\157\x72\x4d\145\163\163\x61\x67\x65\x25" => $e->getMessage()])); } goto cf3d8; E2042: if (true === $form->isValid()) { goto D9865; } goto D499f; D499f: $this->formErrors = $this->getErrorMessages($form); goto a3010; cf3d8: C32e1: goto D2b5e; f8491: D9865: goto abba3; a3010: goto C32e1; goto f8491; D2b5e: } public function newPhpSite(Request $request) : Response { goto Ce34b; d8262: $response = $this->render("\x46\162\157\156\x74\145\156\x64\57\123\x69\x74\x65\x2f\x4e\x65\x77\57\x70\150\160\56\150\x74\x6d\154\x2e\164\x77\151\147", ["\165\163\x65\162" => $user, "\x66\x6f\162\x6d" => $form->createView(), "\146\x6f\x72\x6d\105\162\162\157\162\163" => $this->formErrors]); goto Cecfb; Bcf61: dfbd2: goto Eb416; Fd5ec: goto E7492; goto fd978; fd978: b18d5: goto a88eb; Ffbdb: if (!(false === is_null($response))) { goto dfbd2; } goto B6c38; bb502: $response = $this->handleCreatePhpSiteForm($request, $form); goto Ffbdb; Ec8dc: B3cd4: goto d8262; a3a9a: if (!(true === $request->isMethod("\120\x4f\123\x54"))) { goto B3cd4; } goto B7d02; e3f68: if (!(true === $form->isSubmitted())) { goto C5b7b; } goto bb502; a3e94: $form = $this->createPhpSiteForm(); goto a3a9a; Ce34b: $hasPermissions = $this->hasPermissions(); goto E66d6; B6c38: return $response; goto Bcf61; E66d6: if (true === $hasPermissions) { goto b18d5; } goto E11fe; a3c39: return $response; goto D8c0f; a88eb: $user = $this->getUser(); goto a3e94; Eb416: C5b7b: goto Ec8dc; B7d02: $form->handleRequest($request); goto e3f68; Cecfb: E7492: goto a3c39; E11fe: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\x73\151\x74\145\163")); goto Fd5ec; D8c0f: } private function createPhpSiteForm() : Form { goto c1c72; c92ce: $form->add("\163\165\142\155\x69\164", SubmitType::class, ["\x61\x74\164\x72" => ["\x63\154\x61\163\163" => "\142\164\x6e\40\x62\164\156\x2d\x6c\147\x20\142\164\156\55\x62\154\x75\145"], "\154\x61\142\x65\x6c" => "\103\162\x65\141\x74\x65"]); goto f1b4e; f1b4e: return $form; goto Ff697; c1c72: $form = $this->createForm("\x41\x70\160\x5c\x46\x6f\x72\155\134\123\x69\x74\x65\x4e\x65\x77\x50\x68\160\x54\171\160\x65", [], ["\x61\143\164\x69\157\156" => $this->generateUrl("\x63\154\x70\137\x73\x69\x74\x65\137\160\x68\160\137\x6e\145\167"), "\155\x65\x74\x68\157\144" => "\120\x4f\x53\124", "\x61\x74\164\162" => []]); goto c92ce; Ff697: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto De567; De567: if (true === $form->isValid()) { goto f4c0e; } goto a2899; D466e: f4c0e: goto A7204; A7204: try { goto bd1db; F82f9: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto f0a03; c3baf: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Ffae3; Deeeb: $phpVersion = $form->get("\x70\x68\x70\x56\145\162\163\151\x6f\156")->getData(); goto Eae17; Aa201: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto Cda9a; } goto F82f9; bc4c9: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto a9094; } goto b3228; f1813: $response = $this->redirect($this->generateUrl("\143\154\x70\137\163\x69\x74\x65\x73")); goto E9897; Cc7ae: $user = $this->getUser(); goto cd722; cd722: $rootDirectory = $domainName; goto bc4c9; ef8c9: Abd11: goto aabec; B92cb: goto Abd11; goto c16aa; c16aa: Cc1ac: goto Cc7ae; f0a03: Cda9a: goto C1fe6; c4325: $varnishCacheSettings = []; goto Aa201; C1fe6: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto fa1d6; a9eef: throw new \Exception(sprintf("\x56\x68\157\x73\164\40\164\145\x6d\160\x6c\141\164\145\40\x22\45\x73\42\40\x6e\157\x74\40\x66\x6f\165\x6e\x64\56", $vhostTemplateName)); goto B92cb; bd1db: $session = $request->getSession(); goto B013a; e4a89: $siteUserPassword = $form->get("\163\151\164\x65\125\163\x65\162\x50\x61\x73\x73\x77\x6f\162\x64")->getData(); goto c3baf; E2fce: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto f0085; b3228: $rootDirectory = sprintf("\45\x73\57\x25\163", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\x2f"), "\57")); goto b3445; f0085: $session->getFlashBag()->set("\x73\x75\x63\143\x65\x73\163", $this->translator->trans("\123\x69\x74\145\x20\150\x61\x73\x20\x62\145\x65\156\40\143\x72\145\141\x74\x65\x64\56")); goto f1813; B013a: $vhostTemplateName = $form->get("\141\160\160\x6c\151\x63\141\x74\x69\157\156")->getData(); goto Fb739; Fb739: $domainName = $form->get("\x64\157\x6d\141\x69\x6e\x4e\141\x6d\145")->getData(); goto Deeeb; E9897: return $response; goto ef8c9; fa1d6: $eventData = ["\x73\151\164\145" => $domainName, "\x76\x68\x6f\x73\164\124\x65\155\x70\x6c\x61\164\145\116\x61\155\x65" => $vhostTemplateName, "\160\150\x70\126\x65\162\163\x69\157\156" => $phpVersion, "\x73\x69\164\145\x55\163\145\x72" => $siteUser]; goto E2fce; b3445: a9094: goto c4325; Eae17: $siteUser = $form->get("\x73\x69\x74\x65\x55\x73\145\x72")->getData(); goto e4a89; Ffae3: if (false === is_null($vhostTemplateEntity)) { goto Cc1ac; } goto a9eef; aabec: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\156\x67\x65\x72", $this->translator->trans("\101\x6e\40\145\162\162\157\162\40\150\141\x73\x20\x6f\x63\x63\x75\162\x72\145\x64\x2c\40\145\162\x72\x6f\162\x20\x6d\x65\x73\163\x61\147\x65\x3a\x20\45\145\162\x72\x6f\162\x4d\145\163\x73\141\147\x65\x25", ["\45\x65\162\162\x6f\x72\115\x65\163\x73\x61\x67\145\x25" => $e->getMessage()])); } goto B6abc; a2899: $this->formErrors = $this->getErrorMessages($form); goto f0cb2; f0cb2: goto E5322; goto D466e; B6abc: E5322: goto Ea441; Ea441: } public function newWordPressSite(Request $request) : Response { goto Fe781; F6ac6: A2ef8: goto e82ce; ef63f: be615: goto C4b9f; ce904: f8982: goto a967f; a172b: if (!(false === is_null($response))) { goto A2ef8; } goto Ea9e0; Fe781: $hasPermissions = $this->hasPermissions(); goto e2081; F764d: goto be615; goto ce904; f3f7e: $form = $this->createWordPressSiteForm(); goto fddc0; e82ce: e7cbc: goto f617a; e2081: if (true === $hasPermissions) { goto f8982; } goto C34b3; C4b9f: return $response; goto B2114; E88a4: $form->handleRequest($request); goto B23d2; B23d2: if (!(true === $form->isSubmitted())) { goto e7cbc; } goto c5f85; fddc0: if (!(true === $request->isMethod("\120\117\x53\x54"))) { goto cdf88; } goto E88a4; feae6: $response = $this->render("\x46\x72\157\156\x74\x65\156\144\x2f\123\151\x74\145\x2f\x4e\x65\x77\57\167\x6f\162\x64\160\162\x65\x73\163\x2e\x68\x74\x6d\x6c\x2e\164\x77\x69\147", ["\165\163\145\162" => $user, "\146\x6f\x72\x6d" => $form->createView(), "\x66\x6f\x72\155\105\162\x72\x6f\x72\163" => $this->formErrors]); goto ef63f; f617a: cdf88: goto feae6; c5f85: $response = $this->handleCreateWordPressSiteForm($request, $form); goto a172b; a967f: $user = $this->getUser(); goto f3f7e; Ea9e0: return $response; goto F6ac6; C34b3: $response = $this->redirect($this->generateUrl("\x63\154\160\137\x73\x69\x74\145\163")); goto F764d; B2114: } private function createWordPressSiteForm() : Form { goto a2220; a2220: $form = $this->createForm("\101\x70\160\x5c\x46\157\x72\x6d\x5c\x53\x69\164\145\x4e\145\167\x57\x6f\x72\144\120\162\145\163\163\124\171\x70\145", [], ["\141\x63\x74\x69\157\x6e" => $this->generateUrl("\143\154\160\137\x73\x69\x74\x65\137\x77\157\162\x64\x70\x72\x65\x73\x73\137\156\x65\167"), "\155\x65\164\150\x6f\144" => "\x50\117\123\x54", "\141\x74\x74\162" => ["\x69\144" => "\x6e\x65\x77\x2d\167\x6f\162\144\160\162\x65\163\163\55\163\x69\x74\145\x2d\146\157\162\x6d"]]); goto B9d6f; F68ae: return $form; goto fcf6b; B9d6f: $form->add("\163\x75\x62\x6d\x69\x74", SubmitType::class, ["\x61\164\164\x72" => ["\x63\x6c\141\x73\x73" => "\142\x74\x6e\x20\142\x74\x6e\x2d\154\x67\x20\142\164\x6e\x2d\x62\154\165\x65"], "\x6c\x61\142\x65\154" => "\x43\162\x65\x61\164\145"]); goto F68ae; fcf6b: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto a5960; A002b: try { goto b5ef3; c8cc2: $databaseUserEntity->setUserName($databaseUserName); goto B476e; A49cf: $databaseEntity = $this->databaseEntityManager->createEntity(); goto D72bf; F3bd7: $siteCredentials = [$this->translator->trans("\x53\151\164\145") => [$this->translator->trans("\x49\x50\x20\101\x64\x64\162\x65\163\163") => $instance->getIpv4PublicIp(), $this->translator->trans("\x44\x6f\x6d\141\151\156\40\x4e\141\x6d\145") => sprintf("\150\164\x74\x70\163\72\57\x2f\x25\x73", $domainName), $this->translator->trans("\x53\x69\x74\x65\40\125\x73\145\162") => $siteUser, $this->translator->trans("\x50\141\163\x73\x77\x6f\x72\144") => $siteUserPassword]]; goto B1724; F8d84: C9bfd: goto a6fc0; c9f49: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto F8d84; C414c: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto c8cc2; dcca9: $eventData = ["\163\x69\164\145" => $domainName, "\x73\x69\x74\x65\125\x73\145\x72" => $siteUser]; goto f8d4f; d6f3b: $databaseUserEntity->setDatabase($databaseEntity); goto Efcbf; C3185: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto e7e68; F0afb: $databaseEntity->setSite($siteEntity); goto C414c; F4cbd: $databaseManager->createDatabase($databaseEntity); goto a8c28; A93cf: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto A49cf; B1724: if (!(false === is_null($siteEntity))) { goto Dacc2; } goto a7be9; c36fe: $domainName = $form->get("\x64\x6f\x6d\x61\151\x6e\116\x61\155\145")->getData(); goto A6cb4; d2e80: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto Af112; d4222: $isMultiSite = $form->get("\155\165\154\164\151\x53\x69\164\x65")->getData(); goto A93cf; B9e4e: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Fcb96; Dfef3: $siteUser = $form->get("\163\x69\164\x65\125\163\x65\x72")->getData(); goto Ef2b3; d3271: Dacc2: goto Ab321; Ab321: $session->set("\x73\151\x74\x65\x43\162\145\x64\x65\x6e\164\x69\141\154\x73", $siteCredentials); goto dcca9; Dd744: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto d6f3b; D312b: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto aef18; b5ef3: $user = $this->getUser(); goto b9e13; A90a7: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\163\151\x74\145\x5f\x77\x6f\x72\144\160\x72\145\163\163\x5f\x69\x6e\163\164\x61\x6c\x6c\145\x64")); goto ac20e; b9e13: $session = $request->getSession(); goto c36fe; ac20e: return $response; goto B9c83; a424a: $siteCredentials["\127\x6f\162\x64\120\x72\145\163\163"] = [$this->translator->trans("\101\x64\155\x69\156\x20\105\55\x4d\141\x69\x6c") => $adminEmail, $this->translator->trans("\101\144\x6d\151\156\40\x55\163\x65\x72\x20\116\141\x6d\145") => $adminUserName, $this->translator->trans("\x41\144\155\x69\156\x20\x50\141\163\x73\x77\x6f\162\x64") => $adminPassword, $this->translator->trans("\101\144\x6d\151\x6e\40\x55\x72\x6c") => sprintf("\x68\164\164\x70\163\x3a\x2f\x2f\x25\x73\57\x77\160\x2d\141\144\155\x69\156\x2f", rtrim($domainName, "\57"))]; goto d3271; e7e68: $siteCredentials[$this->translator->trans("\104\x61\x74\x61\x62\141\163\x65")] = [$this->translator->trans("\x48\157\163\164") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\120\x6f\162\x74") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\x44\x61\164\141\x62\x61\163\x65\40\x4e\141\x6d\x65") => $databaseName, $this->translator->trans("\x44\141\x74\141\142\x61\163\145\40\x55\163\145\x72\x20\116\141\x6d\x65") => $databaseUserName, $this->translator->trans("\104\141\164\x61\142\141\x73\145\40\x55\163\145\x72\40\x50\x61\x73\163\x77\x6f\162\144") => $databaseUserPassword]; goto a424a; Cddf0: $databaseEntity->setName($databaseName); goto F0afb; Af112: $url = sprintf("\150\x74\x74\160\163\x3a\x2f\x2f\x25\163", $siteEntity->getDomainName()); goto B2a55; Fcb96: $instance = $request->attributes->get("\151\156\163\x74\x61\x6e\x63\x65"); goto F3bd7; D71f3: $adminPassword = $form->get("\141\144\155\151\156\120\141\x73\x73\167\157\162\144")->getData(); goto c78bd; a7be9: $databaseName = $this->getUniqueDatabaseName($generatedName); goto f8737; B476e: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto Dd744; B2a55: $title = $form->get("\x73\151\x74\x65\x54\x69\x74\154\145")->getData(); goto ffc4c; A6cb4: $generatedName = $this->generateNameFromDomainName($domainName); goto Dfef3; e33d4: $siteEntity->addDatabase($databaseEntity); goto Cf307; a6fc0: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto B9e4e; a8c28: $databaseManager->createUser($databaseUserEntity); goto bbb07; Cf307: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto F4cbd; f8d4f: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto A90a7; adf05: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto C9bfd; } goto c9f49; aef18: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto b4b1c; Efcbf: $databaseEntity->addUser($databaseUserEntity); goto e33d4; D72bf: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto Cddf0; b4b1c: $varnishCacheSettings = []; goto adf05; f8737: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto d2e80; Ef2b3: $siteUserPassword = $form->get("\163\x69\164\145\x55\x73\x65\162\x50\x61\x73\x73\167\157\x72\144")->getData(); goto D312b; bbb07: $this->siteEntityManager->updateEntity($siteEntity); goto C3185; ffc4c: $adminUserName = $form->get("\x61\144\x6d\151\x6e\125\163\145\x72\116\141\x6d\145")->getData(); goto D71f3; c78bd: $adminEmail = $form->get("\x61\144\155\151\156\105\x6d\x61\151\154")->getData(); goto d4222; B9c83: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\x67\145\162", $this->translator->trans("\101\156\40\145\162\162\157\x72\40\150\141\x73\40\x6f\143\x63\x75\162\x72\145\144\54\40\x65\x72\162\x6f\x72\x20\155\145\x73\163\141\x67\145\x3a\x20\x25\x65\x72\x72\x6f\162\115\x65\163\163\141\x67\x65\45", ["\45\145\162\162\157\x72\115\145\163\163\141\x67\145\x25" => $e->getMessage()])); } goto b8732; edc54: $this->formErrors = $this->getErrorMessages($form); goto Aa55f; Aa55f: goto D9fc7; goto Fb684; a5960: if (true === $form->isValid()) { goto Ab424; } goto edc54; b8732: D9fc7: goto Bd5f7; Fb684: Ab424: goto A002b; Bd5f7: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto E50e8; C4573: Dd0d4: goto F2a7e; Eb71a: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\141\x6c\x75\145"], $config["\162\x61\x77"]); deb6a: } goto d4e7f; ab363: $wordPressInstaller = new WordPressInstaller($siteEntity); goto Cecbb; B815d: $databaseName = $databaseEntity->getName(); goto C9e06; E26bb: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto ab363; E50e8: $databaseHost = sprintf("\45\x73\72\x25\163", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto B815d; eabee: $this->wordPressMultiSiteConfigValues["\104\x4f\x4d\x41\111\x4e\137\x43\125\x52\x52\x45\116\124\137\x53\111\x54\x45"]["\166\141\x6c\165\x65"] = $siteEntity->getDomainName(); goto Bd900; d4e7f: A7d2b: goto bc795; bc795: if (!(true === $isMultiSite)) { goto Dfe07; } goto eabee; cb155: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto Eb71a; C9e06: $databaseUserName = $databaseUserEntity->getUserName(); goto E26bb; F2a7e: Dfe07: goto D545d; D545d: $wordPressInstaller->resetPermissions(); goto ff972; Bd900: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\x61\x6c\165\145"], $config["\162\x61\x77"]); f9f50: } goto C4573; Cecbb: $wordPressInstaller->downloadAndExtractLatestVersion(); goto Ba912; Ba912: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto cb155; ff972: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto d37ab; df3b5: if (!(true === is_null($subdomain))) { goto Bff91; } goto f59b5; d2445: $vhostTemplate = new PhpVhostTemplate($phpSite); goto Bdd82; b8035: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto A3160; B89ac: $rsaKeyGenerator = new RsaKeyGenerator(); goto Beba5; db5aa: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto dabe0; A7533: goto bc07f; goto ab6c2; dc054: $phpSiteCreator->createLogrotateFile(); goto c86f5; c86f5: $phpSiteCreator->createIndexPhp(); goto cbeb0; B0158: if (!(true === $varnishCache)) { goto e5fce; } goto cfdfe; ac940: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto f20f8; a099b: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto A10ef; b4065: $siteEntity->setUserPassword($siteUserPassword); goto Edb1a; e6f19: $vhostTemplate->resetProcessors(); goto f9ea4; Bd576: $siteEntity->setVarnishCache(true); goto fdd6a; Af661: $phpSite = new PhpSite(); goto Adbeb; F464d: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto F9987; f2e9e: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto f1ad5; F6079: if (!(false === empty($varnishCache))) { goto Dcbbb; } goto Bd576; cfdfe: $phpSite->setVarnishCache(true); goto Da1b2; dabe0: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto D7ab1; f68eb: $siteEntity->setCertificate($certificateEntity); goto Af661; b3e2e: $phpSite->setRegistrableDomain($registrableDomain); goto b1237; f1584: $phpSettingsEntity->setPhpVersion($phpVersion); goto Fb660; df245: $constraintViolationList->addAll($phpSettingsConstraints); goto E7b97; B3c72: $siteEntity->setVhostTemplate($vhostTemplate); goto Cfa75; ce0b7: e5fce: goto Dacd5; D8528: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto b545f; B2a5f: return $siteEntity; goto Ed9b1; bcefb: $phpSite->setDomainName($domainName); goto b3e2e; A10ef: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto efc58; B25f9: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto A57cd; efc58: $csr = $csrGenerator->generate(); goto ac940; Cfa75: $phpSettingsEntity = new PhpSettingsEntity(); goto e6ee4; fae4e: $siteEntity->setDomainName($domainName); goto Aeb61; Fb131: $siteEntity->setType(SiteEntity::TYPE_PHP); goto fae4e; Ed43f: $constraintViolationList->addAll($siteConstraints); goto df245; fdd6a: Dcbbb: goto A5bef; Edb1a: $siteEntity->setRootDirectory($rootDirectory); goto F6079; F39f4: $phpSiteCreator->resetPermissions(); goto d2445; f9ea4: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto db5aa; A57cd: $this->siteEntityManager->updateEntity($siteEntity); goto B2a5f; d90af: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto B8c4a; F8821: $certificateEntity->setSite($siteEntity); goto B89ac; b1237: $phpSite->setSubdomain($subdomain); goto Baea5; bacdf: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\x2e\x2e\x2f\x2e\x2e\x2f\162\145\163\157\165\162\x63\x65\163\57\156\147\x69\156\x78\x2f\166\150\x6f\163\x74\x5f\164\x65\x6d\160\x6c\x61\164\145\x2f\x72\145\x64\x69\162\x65\143\x74\x2d\x68\x74\x74\x70\63"); goto D4d54; fd8f5: $certificateEntity = $this->certificateEntityManager->createEntity(); goto F8821; Baea5: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto de65c; f59b5: $subjectAlternativeNames[] = sprintf("\x77\167\167\56\x25\163", $domainName); goto ac3cc; b545f: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto B8772; e6ee4: $siteEntity->setPhpSettings($phpSettingsEntity); goto f1584; b96dd: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto D7c4d; ccf5b: $subjectAlternativeNames = []; goto df3b5; fc61e: $subdomain = $resolvedDomainName->subDomain()->toString(); goto B9e00; F9987: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto D8187; } goto E1eb9; F4629: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto bcefb; E7b97: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto B9d3c; a79e1: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Ab63c; Beba5: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto ccf5b; ffaf4: $phpSiteCreator->createPhpFpmPool(); goto E4d27; A5bef: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto C92df; } goto f3cb6; cb95d: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\56\56\57\x2e\x2e\57\162\x65\x73\157\x75\x72\143\x65\x73\57\x6e\147\x69\156\170\x2f\166\150\x6f\x73\x74\137\x74\x65\155\x70\154\141\164\145\57\x72\x65\x64\x69\x72\145\143\164"); goto A7533; f438c: $phpSiteCreator->reloadNginxService(); goto F39f4; Ab63c: $certificateEntity->setCsr($csr); goto f2e9e; Bdd82: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto e6f19; Dacd5: $phpSiteCreator->createNginxVhost(); goto f438c; B8772: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto ce0b7; Cfff6: $phpSiteCreator->createRootDirectory(); goto dc054; D4d54: bc07f: goto d90af; da910: $vhostTemplate = sprintf("\45\x73\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto B3487; Adbeb: $phpSite->setUser($siteEntity->getUser()); goto F4629; f20f8: $certificateEntity->setDefaultCertificate(true); goto a79e1; B9e00: $subdomain = false === empty($subdomain) ? $subdomain : null; goto D1b64; Aed0d: C92df: goto B3c72; D7ab1: $vhostTemplate->build(); goto D4df3; c7d23: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto e540b; Da1b2: $defaultVarnishCacheSettings = ["\x65\156\x61\x62\154\145\144" => false, "\x73\145\x72\x76\145\x72" => self::VARNISH_CACHE_SERVER, "\x63\141\143\x68\x65\124\141\x67\x50\x72\x65\146\x69\x78" => substr(md5(time()), 0, 4)]; goto D8528; ac3cc: Bff91: goto d92e8; B9d3c: throw new \Exception(implode("\73\40", $errorMessages)); goto bc896; bc896: D8187: goto fd8f5; d37ab: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto A3ccc; f3cb6: if (true === isset($_ENV["\101\x50\120\x5f\110\124\x54\120\63"]) && "\x74\162\165\x65" === $_ENV["\101\x50\x50\x5f\110\x54\x54\x50\63"]) { goto d28e8; } goto cb95d; E1eb9: $constraintViolationList = new ConstraintViolationList(); goto Ed43f; de65c: $phpSite->setCertificate($certificateEntity); goto Ee3e7; E4d27: $phpSiteCreator->reloadPhpFpmService(); goto B0158; Aeb61: $siteEntity->setUser($siteUser); goto b4065; d92e8: if (!(false === is_null($subdomain) && "\x77\167\167" == $subdomain)) { goto adbca; } goto Eb19a; Eb19a: $subjectAlternativeNames[] = $registrableDomain; goto Ceec5; Ee3e7: $phpSite->setPhpSettings($phpSettingsEntity); goto c7d23; B3487: A743e: goto Aed0d; B2f11: $siteConstraints = $this->validator->validate($siteEntity); goto F464d; f1ad5: $certificateEntity->setCertificate($selfSignedCertificate); goto f68eb; E849a: $phpSiteCreator->createUser(); goto Cfff6; B8c4a: if (!(false === empty($redirectionVhostTemplate))) { goto A743e; } goto da910; e540b: $phpSiteCreator = new PhpSiteCreator($phpSite); goto E849a; A3ccc: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\57")), "\57"); goto b96dd; ab6c2: d28e8: goto bacdf; D4df3: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto B25f9; Ceec5: adbca: goto a099b; D7c4d: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto fc61e; D1b64: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto b8035; Fb660: $phpSettingsEntity->setSite($siteEntity); goto B2f11; cbeb0: $phpSiteCreator->createPrivateKeyAndCertificate(); goto ffaf4; A3160: $siteEntity = $this->siteEntityManager->createEntity(); goto Fb131; Ed9b1: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto F0660; ba7bb: $nodejsSite->setRegistrableDomain($registrableDomain); goto b91fa; A2cdc: $certificateEntity->setSite($siteEntity); goto adff3; ae926: if (!(true === is_null($subdomain))) { goto C50b0; } goto f6713; E5a4e: $certificateEntity->setCsr($csr); goto Ce46a; b6ff3: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto bc7a9; Fd42a: $nodejsSettingsEntity->setSite($siteEntity); goto dd66c; F300f: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto f586f; F9361: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto E388f; f7dd6: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto ae409; f586f: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto a2e74; B03a9: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto cee24; a1963: $constraintViolationList->addAll($nodejsSettingsConstraints); goto f3aed; b44e1: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto D678b; adff3: $rsaKeyGenerator = new RsaKeyGenerator(); goto F9361; Da34d: $nodejsSiteCreator->createRootDirectory(); goto b4449; cee24: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto C53f7; e056d: $siteEntity->setRootDirectory($domainName); goto a8533; F0660: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto b44e1; b687b: $certificateEntity->setCertificate($selfSignedCertificate); goto C4853; B6a02: E8f59: goto c4304; b91fa: $nodejsSite->setSubdomain($subdomain); goto E7610; c4304: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\56\x2e\57\x2e\56\x2f\162\145\163\157\x75\162\143\145\x73\x2f\156\147\151\156\170\57\166\x68\x6f\163\x74\x5f\x74\x65\x6d\x70\154\x61\x74\x65\x2f\x72\145\x64\x69\x72\x65\x63\164\x2d\150\x74\164\x70\x33"); goto A0a8e; Be4b1: if (!(false === empty($redirectionVhostTemplate))) { goto B6d1e; } goto e4827; c3f12: $nodejsSite->setDomainName($domainName); goto ba7bb; Ebe06: $vhostTemplate->resetProcessors(); goto bcbce; C1d08: $certificateEntity->setDefaultCertificate(true); goto fa4c1; a8533: if (!(true === is_null($subdomain) || "\167\x77\167" == $subdomain)) { goto Cc53a; } goto B280d; B1017: Ca853: goto Ebde7; A9edb: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto f97d8; a712f: $subjectAlternativeNames[] = $registrableDomain; goto b1b3a; C6a15: $siteEntity->setUser($siteUser); goto D38c0; f3909: $nodejsSiteCreator->createNvmDirectory(); goto fcc6b; dd66c: $siteConstraints = $this->validator->validate($siteEntity); goto A9edb; ae409: $this->siteEntityManager->updateEntity($siteEntity); goto Cb3ca; bc7a9: $csr = $csrGenerator->generate(); goto f8c4d; f3aed: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Bb2ba; A9260: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto b6ff3; Cb3ca: return $siteEntity; goto E4545; F44e4: B6d1e: goto C3f4b; Ce46a: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto b687b; b4449: $nodejsSiteCreator->createLogrotateFile(); goto f3909; aa793: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto Be4b1; Ad3e0: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto fb233; Dc434: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\x2f\x2e\56\57\56\56\57\x72\x65\x73\157\x75\162\143\x65\163\57\x6e\147\x69\156\170\x2f\166\x68\157\163\x74\137\x74\x65\x6d\160\154\x61\x74\x65\x2f\162\x65\144\x69\x72\x65\x63\164"); goto A9eb6; C53f7: $nodejsSettingsEntity->setPort($port); goto Fd42a; dc137: C50b0: goto e9a2d; Ebde7: $certificateEntity = $this->certificateEntityManager->createEntity(); goto A2cdc; F956f: $nodejsSiteCreator->createNginxVhost(); goto A51f3; fa4c1: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto E5a4e; fb233: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Ebe06; A2fd6: $siteEntity->setVhostTemplate($vhostTemplate); goto D5c0c; e9a2d: if (!(false === is_null($subdomain) && "\x77\x77\x77" == $subdomain)) { goto e38a1; } goto a712f; A51f3: $nodejsSiteCreator->reloadNginxService(); goto Fe722; D1667: $nodejsSite->setCertificate($certificateEntity); goto e83c7; e83c7: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto F300f; e1d03: $subdomain = false === empty($subdomain) ? $subdomain : null; goto dd6c1; bcbce: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto F93f5; a2e74: $nodejsSiteCreator->createUser(); goto Da34d; C4853: $siteEntity->setCertificate($certificateEntity); goto D367f; F0541: $siteEntity = $this->siteEntityManager->createEntity(); goto e3058; Bb2ba: throw new \Exception(implode("\73\x20", $errorMessages)); goto B1017; E7610: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto D1667; A9eb6: goto Ca825; goto B6a02; B280d: if (true === isset($_ENV["\101\120\120\x5f\x48\124\124\120\63"]) && "\164\162\x75\x65" === $_ENV["\x41\120\x50\137\110\x54\x54\120\63"]) { goto E8f59; } goto Dc434; E388f: $subjectAlternativeNames = []; goto ae926; D678b: $subdomain = $resolvedDomainName->subDomain()->toString(); goto e1d03; cc14e: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto f7dd6; Ce756: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto c3f12; A0a8e: Ca825: goto aa793; f8c4d: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto C1d08; b1b3a: e38a1: goto A9260; D367f: $nodejsSite = new NodejsSite(); goto d3fcd; f6713: $subjectAlternativeNames[] = sprintf("\167\x77\167\x2e\45\x73", $domainName); goto dc137; e3058: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto e3602; F93f5: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto ac655; Bcdbb: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto F0541; d3fcd: $nodejsSite->setUser($siteEntity->getUser()); goto Ce756; e3602: $siteEntity->setDomainName($domainName); goto C6a15; d7e0c: $vhostTemplate->build(); goto cc14e; f97d8: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto Ca853; } goto C6d27; e4827: $vhostTemplate = sprintf("\x25\x73\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto F44e4; C6d27: $constraintViolationList = new ConstraintViolationList(); goto f3481; B9b18: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto F956f; D5c0c: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto B03a9; dd6c1: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto Bcdbb; f3481: $constraintViolationList->addAll($siteConstraints); goto a1963; C3f4b: Cc53a: goto A2fd6; Fe722: $nodejsSiteCreator->resetPermissions(); goto Ad3e0; D38c0: $siteEntity->setUserPassword($siteUserPassword); goto e056d; fcc6b: $nodejsSiteCreator->installNodejs(); goto B9b18; ac655: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto d7e0c; E4545: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto Bd63f; a1f9c: $siteEntity->setVhostTemplate($vhostTemplate); goto A7e1c; ed433: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto E0bd6; E1173: $pythonSite->setCertificate($certificateEntity); goto D1d25; D8e06: $pythonSettingsEntity->setSite($siteEntity); goto a72af; D3547: if (!(true === is_null($subdomain))) { goto A9f67; } goto a61d2; a72af: $siteConstraints = $this->validator->validate($siteEntity); goto d5eb8; b5521: $certificateEntity->setDefaultCertificate(true); goto b01f9; D39e5: ab647: goto a1f9c; b93d3: $siteEntity->setCertificate($certificateEntity); goto ef8ea; b01f9: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto c9b28; D8d72: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto D29d9; D36ff: $pythonSiteCreator->resetPermissions(); goto F8747; f95c7: A9f67: goto F5160; Ed82a: $siteEntity->setUser($siteUser); goto A91af; A27ca: $vhostTemplate->build(); goto e1a31; c3789: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto Cf26b; Ef1b2: $constraintViolationList->addAll($siteConstraints); goto F774f; Ecce7: $siteEntity->setRootDirectory($domainName); goto d4531; Bd63f: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto e3103; B4590: $subdomain = $resolvedDomainName->subDomain()->toString(); goto F9aa4; D2ec8: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto f8074; F9aa4: $subdomain = false === empty($subdomain) ? $subdomain : null; goto A6ec7; d4531: if (!(true === is_null($subdomain) || "\167\167\167" == $subdomain)) { goto ab647; } goto cb95e; F8747: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto Da150; c6410: $subjectAlternativeNames = []; goto D3547; D1d25: $pythonSite->setPythonSettings($pythonSettingsEntity); goto b5783; A1c7c: $pythonSiteCreator->writePythonVersionFile(); goto E7d09; Df234: if (!(false === empty($redirectionVhostTemplate))) { goto bd3c9; } goto B70ce; f37a0: $this->siteEntityManager->updateEntity($siteEntity); goto fb503; D1b6b: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\x2f\x2e\56\57\x2e\56\x2f\162\145\163\x6f\165\162\x63\145\x73\x2f\x6e\x67\x69\156\170\57\x76\150\x6f\x73\x74\x5f\164\x65\155\160\x6c\141\x74\x65\57\x72\x65\144\151\x72\x65\143\164\55\150\x74\164\x70\63"); goto F8606; e54cf: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto E1173; c008f: $certificateEntity->setSite($siteEntity); goto df03b; F5b71: $subjectAlternativeNames[] = $registrableDomain; goto c9a5d; B2fec: $pythonSiteCreator->createLogrotateFile(); goto A1c7c; E7d09: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto de372; b2438: $constraintViolationList = new ConstraintViolationList(); goto Ef1b2; F8606: ec9dd: goto E1450; C9041: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto d8314; E1450: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto Df234; fb503: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto cc45a; d5673: bd3c9: goto D39e5; c9a5d: E835a: goto A711a; Aba07: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto dad4e; b8f5e: $siteEntity = $this->siteEntityManager->createEntity(); goto Aba07; e3103: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto B4590; C8c0e: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto C43f5; cb95e: if (true === isset($_ENV["\x41\120\120\137\x48\124\124\x50\63"]) && "\x74\x72\165\145" === $_ENV["\x41\120\120\x5f\110\124\x54\x50\63"]) { goto acf50; } goto Eba43; A6ec7: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto D716b; D29d9: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto aa278; F18f4: $pythonSiteCreator->createRootDirectory(); goto B2fec; B7e63: $pythonSite->setSubdomain($subdomain); goto e54cf; cad77: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto c6410; Eba43: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\56\x2e\x2f\56\56\x2f\162\145\163\157\x75\162\x63\x65\x73\x2f\156\147\x69\x6e\x78\57\166\150\157\163\164\x5f\x74\145\x6d\160\154\141\164\145\x2f\x72\145\x64\151\x72\x65\x63\164"); goto ffcdc; Dfa73: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto C8c0e; e4478: $siteEntity->setPythonSettings($pythonSettingsEntity); goto f9d20; F774f: $constraintViolationList->addAll($pythonSettingsConstraints); goto D8d72; aa278: Ad95e: goto ff475; Ce0b1: acf50: goto D1b6b; A711a: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto c3789; d8314: $certificateEntity->setCertificate($selfSignedCertificate); goto b93d3; d0ba3: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto b5521; a61d2: $subjectAlternativeNames[] = sprintf("\x77\167\x77\56\x25\163", $domainName); goto f95c7; A7e1c: $pythonSettingsEntity = new PythonSettingsEntity(); goto e4478; de372: $pythonSiteCreator->createNginxVhost(); goto d8964; D716b: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto b8f5e; c9b28: $certificateEntity->setCsr($csr); goto C9041; Cf26b: $csr = $csrGenerator->generate(); goto d0ba3; f9d20: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto Bfe61; f0da3: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto Ad95e; } goto b2438; b5783: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto ed433; df03b: $rsaKeyGenerator = new RsaKeyGenerator(); goto cad77; db941: $vhostTemplate->resetProcessors(); goto Dfa73; ffcdc: goto ec9dd; goto Ce0b1; A91af: $siteEntity->setUserPassword($siteUserPassword); goto Ecce7; dad4e: $siteEntity->setDomainName($domainName); goto Ed82a; ff475: $certificateEntity = $this->certificateEntityManager->createEntity(); goto c008f; d8964: $pythonSiteCreator->reloadNginxService(); goto D36ff; ef8ea: $pythonSite = new PythonSite(); goto A29c6; cc45a: return $siteEntity; goto ea661; d5eb8: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto f0da3; Da150: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto db941; C43f5: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto A27ca; F5160: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto E835a; } goto F5b71; F80df: $pythonSite->setRegistrableDomain($registrableDomain); goto B7e63; A29c6: $pythonSite->setUser($siteEntity->getUser()); goto D2ec8; E0bd6: $pythonSiteCreator->createUser(); goto F18f4; f8074: $pythonSite->setDomainName($domainName); goto F80df; Bfe61: $pythonSettingsEntity->setPort($port); goto D8e06; e1a31: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto f37a0; B70ce: $vhostTemplate = sprintf("\x25\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto d5673; ea661: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto e7ee3; b5fa7: a86b9: goto Ae004; E5e9c: Ab40f: goto Dd0c8; Ca573: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Fef43; Ae004: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\x2f\56\56\57\x2e\x2e\57\162\145\x73\157\165\x72\x63\x65\x73\x2f\156\147\151\156\170\x2f\166\x68\157\x73\x74\x5f\x74\x65\x6d\160\154\141\164\145\57\162\145\x64\x69\x72\x65\x63\164\x2d\150\x74\164\x70\63"); goto Ac00a; B8ad5: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto bcfa4; e2972: $csr = $csrGenerator->generate(); goto B8ad5; e0b1a: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto E9f6f; Bfdcc: $siteEntity->setUserPassword($siteUserPassword); goto E3984; D0238: $certificateEntity = $this->certificateEntityManager->createEntity(); goto F859f; f7d8a: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto ea87d; ed09b: $staticSiteCreator->createRootDirectory(); goto A153a; e16bc: $subjectAlternativeNames[] = $registrableDomain; goto Eaee7; E512e: if (!count($siteConstraints)) { goto A7570; } goto Fef1b; da9f9: $staticSite = new StaticSite(); goto Bd877; Ac00a: d480b: goto f7d8a; Dd0c8: if (!(false === is_null($subdomain) && "\x77\x77\x77" == $subdomain)) { goto C98c2; } goto e16bc; A153a: $staticSiteCreator->createLogrotateFile(); goto E1060; c9bc9: $siteEntity->setDomainName($domainName); goto B5ce9; Ce74f: if (!(true === is_null($subdomain))) { goto Ab40f; } goto D4e0e; F558e: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto D0377; Fef1b: $constraintViolationList = new ConstraintViolationList(); goto Cba2a; Ba64b: if (!(true === is_null($subdomain) || "\x77\x77\x77" == $subdomain)) { goto a3b31; } goto B0b0a; Ab690: $this->siteEntityManager->updateEntity($siteEntity); goto D289d; E3287: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto A221d; E1060: $staticSiteCreator->createIndexHtml(); goto c2029; A221d: $subdomain = $resolvedDomainName->subDomain()->toString(); goto ba7e0; Afcbc: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto Cd2a6; bcfa4: $certificateEntity->setDefaultCertificate(true); goto Ca573; E9f5f: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto d068d; D0377: throw new \Exception(implode("\x3b\40", $errorMessages)); goto bc677; d068d: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Afcbc; Ced91: $certificateEntity->setCertificate($selfSignedCertificate); goto d5b9b; a0dbf: $siteEntity->setVhostTemplate($vhostTemplate); goto B8903; d5b9b: $siteEntity->setCertificate($certificateEntity); goto da9f9; Eeedd: $staticSiteCreator->reloadNginxService(); goto D08ea; D4e0e: $subjectAlternativeNames[] = sprintf("\x77\x77\167\56\x25\x73", $domainName); goto E5e9c; ec5a4: $vhostTemplate = new StaticVhostTemplate($staticSite); goto be18b; B5ce9: $siteEntity->setUser($siteUser); goto Bfdcc; c2029: $staticSiteCreator->createPrivateKeyAndCertificate(); goto E8346; A0f91: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto A89f3; f9ba0: $subjectAlternativeNames = []; goto Ce74f; ba7e0: $subdomain = false === empty($subdomain) ? $subdomain : null; goto ba8be; Cd2a6: $vhostTemplate->build(); goto a9b93; Fe395: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto c9bc9; Eaee7: C98c2: goto f344a; fe9c1: cbb89: goto A85cf; eb8f1: $staticSiteCreator = new StaticSiteCreator($staticSite); goto b57f9; D08ea: $staticSiteCreator->resetPermissions(); goto ec5a4; E59c4: $staticSite->setRegistrableDomain($registrableDomain); goto C54b5; B8903: $siteConstraints = $this->validator->validate($siteEntity); goto E512e; ea87d: if (!(false === empty($redirectionVhostTemplate))) { goto cbb89; } goto c7c53; ba8be: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto A0f91; E3984: $siteEntity->setRootDirectory($domainName); goto Ba64b; D3f1e: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto e0603; ce4ca: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Ab690; Aa062: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto e2972; Fef43: $certificateEntity->setCsr($csr); goto e0600; E8346: $staticSiteCreator->createNginxVhost(); goto Eeedd; a7786: goto d480b; goto b5fa7; bc677: A7570: goto D0238; Cba2a: $constraintViolationList->addAll($siteConstraints); goto F558e; Eea84: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\x2f\56\x2e\x2f\56\56\x2f\162\x65\x73\x6f\x75\x72\143\145\x73\57\x6e\147\151\x6e\170\x2f\166\x68\157\163\x74\x5f\x74\x65\x6d\160\x6c\141\164\x65\57\162\145\144\151\162\145\x63\164"); goto a7786; e7ee3: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto E3287; be18b: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto bbf9b; f344a: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Aa062; E9f6f: $staticSite->setDomainName($domainName); goto E59c4; F859f: $certificateEntity->setSite($siteEntity); goto c70bc; bbf9b: $vhostTemplate->resetProcessors(); goto E9f5f; A5e73: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto f9ba0; Bd877: $staticSite->setUser($siteEntity->getUser()); goto e0b1a; c7c53: $vhostTemplate = sprintf("\x25\x73\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto fe9c1; c70bc: $rsaKeyGenerator = new RsaKeyGenerator(); goto A5e73; A85cf: a3b31: goto a0dbf; a9b93: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto ce4ca; B0b0a: if (true === isset($_ENV["\101\x50\x50\137\110\124\x54\120\x33"]) && "\x74\x72\165\145" === $_ENV["\x41\120\x50\137\x48\x54\x54\120\x33"]) { goto a86b9; } goto Eea84; b57f9: $staticSiteCreator->createUser(); goto ed09b; D289d: return $siteEntity; goto f9208; C54b5: $staticSite->setSubdomain($subdomain); goto D3f1e; e0603: $staticSite->setCertificate($certificateEntity); goto Bb72d; e0600: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Ced91; Bb72d: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto eb8f1; A89f3: $siteEntity = $this->siteEntityManager->createEntity(); goto Fe395; f9208: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto F35c8; C020e: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\x2f\56\56\x2f\x2e\56\x2f\x72\145\163\157\x75\x72\x63\x65\163\57\x6e\147\151\x6e\170\57\166\150\x6f\x73\x74\137\x74\x65\x6d\x70\154\141\164\145\57\x72\x65\x64\x69\x72\145\x63\x74\x2d\150\x74\164\160\x33"); goto fb154; a38a8: if (!(false === empty($redirectionVhostTemplate))) { goto f4e14; } goto B799d; De8b9: $certificateEntity->setCsr($csr); goto C33e4; ad53f: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto d4396; a8978: if (true === isset($_ENV["\x41\120\x50\x5f\110\124\124\x50\63"]) && "\164\x72\165\x65" === $_ENV["\101\120\120\x5f\110\x54\124\x50\63"]) { goto cd0e5; } goto Fad86; a3ddc: $this->siteEntityManager->updateEntity($siteEntity); goto da6f2; c104e: goto F3428; goto E6508; F35c8: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto ad53f; a4601: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto a9dd0; Cfcc4: $reversProxySiteCreator->resetPermissions(); goto bb837; a4650: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto De8b9; c7107: $reversProxySiteCreator->createRootDirectory(); goto E2a2a; bc4bb: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto da652; Eda2b: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto bd88b; c96eb: $siteEntity->setVhostTemplate($vhostTemplate); goto f9cb3; A7c5b: $certificateEntity = $this->certificateEntityManager->createEntity(); goto F01be; f9e43: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto a38a8; f2b55: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto C500e; Ff98d: f7068: goto c96eb; B22b9: if (!(true === is_null($subdomain) || "\167\167\167" == $subdomain)) { goto f7068; } goto a8978; bb837: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto Ba7dc; Bb78a: $siteEntity->setCertificate($certificateEntity); goto D7379; fb154: F3428: goto f9e43; f9cb3: $siteConstraints = $this->validator->validate($siteEntity); goto Fe638; Aedde: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto a5847; ad817: $certificateEntity->setDefaultCertificate(true); goto a4650; Fad86: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\x2f\x2e\x2e\x2f\x2e\56\57\x72\145\163\x6f\x75\x72\143\145\163\x2f\156\x67\151\x6e\170\x2f\x76\x68\x6f\x73\164\137\164\145\x6d\x70\x6c\x61\164\x65\57\x72\x65\x64\151\x72\x65\143\164"); goto c104e; a5847: $reverseProxySite->setDomainName($domainName); goto b5614; E6508: cd0e5: goto C020e; Fe638: if (!count($siteConstraints)) { goto d6d69; } goto B633b; bd88b: $subjectAlternativeNames = []; goto A5954; Eb651: $reversProxySiteCreator->createUser(); goto c7107; C33e4: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto bd4fa; d801d: f4e14: goto Ff98d; cf473: $siteEntity->setDomainName($domainName); goto Fe6a9; Aff15: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto Eb651; a9dd0: $vhostTemplate->build(); goto D87de; E2a2a: $reversProxySiteCreator->createLogrotateFile(); goto Ef797; e3258: $reverseProxySite->setUser($siteEntity->getUser()); goto Aedde; Cf216: $subjectAlternativeNames[] = $registrableDomain; goto fb29f; F1077: $siteEntity->setUserPassword($siteUserPassword); goto d5373; A5954: if (!(true === is_null($subdomain))) { goto c215d; } goto Ed05c; C500e: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto f84c2; Ad4a2: $subdomain = false === empty($subdomain) ? $subdomain : null; goto bc4bb; fb29f: Ee82c: goto f2b55; da6f2: return $siteEntity; goto c7f80; F01be: $certificateEntity->setSite($siteEntity); goto e65c3; ad1ff: $siteEntity = $this->siteEntityManager->createEntity(); goto E4e69; Ef797: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto Ef534; E4e69: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto cf473; Fe6a9: $siteEntity->setUser($siteUser); goto F1077; C7714: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto abc5b; B4435: $reversProxySiteCreator->reloadNginxService(); goto Cfcc4; D2904: $constraintViolationList->addAll($siteConstraints); goto b23fa; Ba253: $reverseProxySite->setSubdomain($subdomain); goto bbdb2; fcf59: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto a4601; b5614: $reverseProxySite->setRegistrableDomain($registrableDomain); goto Ba253; De6b2: throw new \Exception(implode("\x3b\40", $errorMessages)); goto D8380; d4396: $subdomain = $resolvedDomainName->subDomain()->toString(); goto Ad4a2; E3078: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto B22b9; B799d: $vhostTemplate = sprintf("\45\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto d801d; D7379: $reverseProxySite = new ReverseProxySite(); goto e3258; B633b: $constraintViolationList = new ConstraintViolationList(); goto D2904; b6431: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto a3ddc; cf542: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto fcf59; b23fa: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto De6b2; Ef534: $reversProxySiteCreator->createNginxVhost(); goto B4435; da652: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto ad1ff; bbdb2: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto fe329; abc5b: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Aff15; e7d07: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto ad817; ea5e2: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto Ee82c; } goto Cf216; d5373: $siteEntity->setRootDirectory($domainName); goto E3078; f84c2: $csr = $csrGenerator->generate(); goto e7d07; E3488: c215d: goto ea5e2; D8380: d6d69: goto A7c5b; Ae2de: $vhostTemplate->resetProcessors(); goto cf542; Ed05c: $subjectAlternativeNames[] = sprintf("\x77\x77\x77\x2e\45\163", $domainName); goto E3488; e65c3: $rsaKeyGenerator = new RsaKeyGenerator(); goto Eda2b; fe329: $reverseProxySite->setCertificate($certificateEntity); goto C7714; bd4fa: $certificateEntity->setCertificate($selfSignedCertificate); goto Bb78a; Ba7dc: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Ae2de; D87de: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto b6431; c7f80: } public function installedWordPressSite(Request $request) : Response { goto b2eef; Abc65: $siteCredentials = $session->get("\163\x69\164\145\x43\x72\145\144\145\x6e\x74\151\141\154\x73"); goto A153f; B57bc: dba4f: goto C2b09; C2b09: return $response; goto Efcee; b2eef: $session = $request->getSession(); goto Abc65; b608d: goto dba4f; goto B2e20; E6efe: return $response; goto B57bc; B2e20: Bdab0: goto d6bc4; Aff75: $response = $this->render("\x46\x72\x6f\x6e\164\x65\x6e\144\57\123\x69\x74\145\57\116\x65\167\57\x77\x6f\x72\x64\x70\x72\145\163\163\x2d\151\156\163\x74\x61\x6c\154\x65\x64\x2e\x68\x74\155\x6c\x2e\x74\x77\151\x67", ["\x73\151\x74\x65\x43\162\145\x64\145\x6e\x74\x69\141\154\x73" => $siteCredentials]); goto E6efe; A153f: if (false === empty($siteCredentials)) { goto Bdab0; } goto E5e45; E5e45: $response = $this->redirect($this->generateUrl("\143\154\x70\137\x73\151\x74\x65\163")); goto b608d; d6bc4: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto Aff75; Efcee: } private function renderSiteCredentials(array $siteCredentials) : string { goto a89b4; Ed3d9: foreach ($siteCredentials as $section => $sectionData) { goto B7854; dc095: $renderedCredentials .= "\x2d\x2d\55\x2d\55\x2d\55\x2d\55\55\x2d\x2d\55\55\55\55\x2d\55\x2d\55\55\x2d\x2d\x2d\55\x2d\55\x2d\55\x2d\x2d\55\55\x2d\55\x2d\55\x2d\55\55\x2d\x2d\55\x2d\x2d\55\x2d\55\55\x2d\x2d\55\55\55" . PHP_EOL; goto c1838; B7854: $renderedCredentials .= $section . PHP_EOL; goto dc095; F887e: $renderedCredentials .= PHP_EOL; goto B1929; c1838: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\45\x73\72\40\x25\163", $key, $value) . PHP_EOL; b3a3a: } goto bc20d; B1929: f410a: goto e8756; bc20d: F2797: goto F887e; e8756: } goto C2e69; C2e69: A3296: goto dad16; dad16: return $renderedCredentials; goto eefd5; a89b4: $renderedCredentials = ''; goto Ed3d9; eefd5: } private function getVhostTemplateEntity(string $name) : mixed { goto Ff3ee; da718: throw new \Exception($this->translator->trans("\x56\150\157\x73\164\40\x54\145\x6d\160\154\141\x74\x65\x20\x25\x76\x68\157\x73\164\x54\145\x6d\x70\154\x61\x74\x65\45\40\x64\157\145\163\40\156\157\x74\x20\x65\170\151\x73\x74\56", ["\45\x76\150\x6f\x73\164\x54\145\x6d\x70\x6c\x61\164\145\x25" => $name])); goto D7ad2; Ff3ee: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto ff2ba; D7ad2: a7cb0: goto f8c64; f8c64: return $vhostTemplateEntity; goto c1390; ff2ba: if (!(true === is_null($vhostTemplateEntity))) { goto a7cb0; } goto da718; c1390: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto E769b; E48ed: return $errorMessages; goto E49d0; A31f6: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\x25\163\72\x20\x25\x73", $constraint->getPropertyPath(), $constraint->getMessage()); C8a75: } goto b659c; E769b: $errorMessages = []; goto A31f6; b659c: ef618: goto E48ed; E49d0: } private function generateNameFromDomainName(string $domainName) : string { goto a19f1; f6fd2: Bb015: goto dc55f; Db2da: $name = $explodedRegistrableDomain[0] ?? ''; goto f6fd2; E4360: d0487: goto Eb784; Bcca3: $name = $explodedRegistrableDomain[0] ?? ''; goto fa2fe; Cec37: bdd00: goto Db2da; dc55f: return $name; goto A41b6; a19f1: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto F695f; f3647: $subdomain = $resolvedDomainName->subDomain()->toString(); goto cc19e; f5249: $explodedSubdomain = explode("\x2e", $subdomain); goto A1674; fa2fe: if (!(false === empty($subdomain))) { goto d0487; } goto f5249; F695f: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto f3647; cc19e: $explodedRegistrableDomain = explode("\56", $registrableDomain); goto E08fb; Eb784: goto Bb015; goto Cec37; A1674: $name = sprintf("\45\163\55\x25\163", $explodedRegistrableDomain[0] ?? '', implode("\x2d", $explodedSubdomain)); goto E4360; E08fb: if ("\x77\x77\x77" == $subdomain) { goto bdd00; } goto Bcca3; A41b6: } private function getUniqueDatabaseName(string $databaseName) : string { goto F5ba8; fa9b8: if (!(strlen($uniqueDatabaseName) <= 3)) { goto cbff8; } goto E2e1e; fad7f: db344: goto c3220; af7ad: cbff8: goto fa286; d60e3: Bd9d0: goto c6056; c6056: if (!(0 < $i)) { goto db344; } goto E45b3; F5ba8: $uniqueDatabaseName = $databaseName; goto fa9b8; E2e1e: $uniqueDatabaseName = sprintf("\x25\163\55\144\x62", $uniqueDatabaseName); goto af7ad; Deb5d: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto b45c8; fe05b: return $uniqueDatabaseName; goto f2491; D3eb0: if (true === $databaseExists) { goto Bd9d0; } goto a73c9; c3220: $databaseExists = in_array($uniqueDatabaseName, $databases); goto F993a; E45b3: $uniqueDatabaseName = sprintf("\45\x73\55\45\x73", $databaseName, $i); goto fad7f; a73c9: a94e4: goto fe05b; b45c8: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto e1df9; F993a: $i++; goto D3eb0; e1df9: $databases = $databaseConnection->getDatabases(); goto d60e3; fa286: $i = 0; goto Deb5d; f2491: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto F72a0; Fef64: $i++; goto ecd93; C093a: Ee930: goto F0fb8; D55b5: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto bb2f7; } goto ff317; F0fb8: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto bc349; Fb3b2: $i = 0; goto A9d47; b95d9: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto Fef64; ff317: $uniqueDatabaseUserName = sprintf("\x25\163\55\x64\x62", $uniqueDatabaseUserName); goto d5a60; f1155: F601c: goto b95d9; ecd93: if (false === is_null($databaseUserEntity)) { goto a223d; } goto C093a; F72a0: $uniqueDatabaseUserName = $databaseUserName; goto D55b5; c8428: if (!(0 < $i)) { goto F601c; } goto cc1bf; bc349: return $uniqueDatabaseUserName; goto a8977; A9d47: a223d: goto c8428; d5a60: bb2f7: goto Fb3b2; cc1bf: $uniqueDatabaseUserName = sprintf("\45\x73\x2d\x25\x73", $databaseUserName, $i); goto f1155; a8977: } private function hasPermissions() : bool { goto A50a4; A50a4: $user = $this->getUser(); goto A03b3; A03b3: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto B4ff6; } goto Bc7ef; B94d4: B4ff6: goto Fbcf6; Bc7ef: return true; goto B94d4; Fbcf6: return false; goto E77bf; E77bf: } }
